@@ -14,24 +14,18 @@
  * limitations under the License.
  */
 
-#include <stdlib.h>
-#include <fstream>
 #include <sstream>
 #include <iostream>
-#include <assert.h>
+#include <cassert>
 
 #include "ErrorHandling.h"			// Util
 #include "CxRITFileHeaderRecords.h"	// DISE
 
 
-
-
 namespace DISE
 {
 
 
-
-
 std::istream& operator>>
 (
 	std::istream&            i_Stream,
@@ -55,8 +49,6 @@ std::istream& operator>>
 }
 
 
-
-
 std::ostream& operator<<
 (
 	std::ostream&                  i_Stream,
@@ -80,8 +72,6 @@ std::ostream& operator<<
 }
 
 
-
-
 void CxRITFileHeaderRecords::GetHeaderRecordSequence
 (
 	std::vector<SHeaderRecordSequenceItem>& o_HeaderRecordSequence
@@ -215,8 +205,6 @@ const
 }
 
 
-
-
 std::istream& CxRITFileHeaderRecords::Read
 (
 	std::istream& i_Stream
@@ -414,8 +402,6 @@ std::istream& CxRITFileHeaderRecords::Read
 }
 
 
-
-
 std::ostream& CxRITFileHeaderRecords::Write
 (
 	std::ostream& i_Stream
@@ -552,8 +538,6 @@ const
 }
 
 
-
-
 std::string CxRITFileHeaderRecords::GetDisplayString
 (
 	const bool	i_CRFlag
@@ -834,16 +818,4 @@ const
 }
 
 
-
-
-
-
-
-
-
-
-
-
-
-
 } // end namespace
