@@ -62,22 +62,16 @@ LOGIC:
 #include <iostream>
 #include <fstream>
 #include <memory>
-#include <string.h>
+#include <cstring>
 #include <deque>
 #include <vector>
 
 #include "GSDS_Volume_F_NBO.h"		// Util
-
-
-
-
 #include "CxRITAnnotation.h"		// DISE
 #include "CSpacecraftID.h"			// DISE
 #include "CSpectralChannelID.h"		// DISE
 
 
-
-
 namespace DISE
 {
 
@@ -95,8 +89,6 @@ struct SPrimaryHeaderRecord
 #pragma pack(pop)
 
 
-
-
 // Encryption Key Message as contained in LRIT/HRIT Encryption Key Message Files.
 #pragma pack(push, 1)
 struct SEncryptionKeyMessage
@@ -109,8 +101,6 @@ struct SEncryptionKeyMessage
 #pragma pack(pop)
 
 
-
-
 // Line Quality Entry structure.
 #pragma pack(push, 1)
 struct SLineQualityEntry
@@ -207,8 +197,6 @@ std::ostream& operator<<
 static const std::vector<DISE::SLineQualityEntry> gs_NoLineQualityEntries;
 
 
-
-
 // File type codes as used in Primary Header Record.
 enum EFileTypeCode
 {
@@ -223,8 +211,6 @@ enum EFileTypeCode
 };
 
 
-
-
 class CxRITFileHeaderRecords
 {
 
@@ -659,8 +645,6 @@ public:
 };
 
 
-
-
 } // end namespace
 
 
